@@ -29,15 +29,22 @@ def report_many_results(ladok, args):
     try:
       student = ladok.get_student(student_id)
       course = student.courses(code=course_code)[0]
-      result = course.results(component=component_code)[0]
-      result.set_grade(grade, date)
-      if args.finalize:
-        result.finalize()
+      component = course.results(component=component_code)[0]
+      if not component.attested and component.grade != grade:
+        component.set_grade(grade, date)
+        component.finalize()
+        if args.verbose:
+          print(f"{course_code} {student}: reported "
+            f"{component.component} = {component.grade}.")
+      elif component.grade != grade:
+        print(f"{course_code} {student}: attested {component.component} "
+          f"result {component.grade} is different from {grade}.")
     except Exception as err:
       try:
-        print(f"{student}: {err}")
+        print(f"{course_code} {component_name} {student}: {err}")
       except ValueError as verr:
-        print(f"{verr}: {args.student_id}: {err}")
+        print(f"{verr}: "
+          f"{course_code} {component_name} {student_id}: {err}")
 
 def add_command_options(parser):
   report_parser = parser.add_parser("report",
@@ -76,6 +83,10 @@ def add_command_options(parser):
     help="The delimiter for the CSV input; "
       "default is a tab character to be compatible with POSIX commands, "
       "use `-d,` or `-d ,` to get comma-separated values.")
+  many_parser.add_argument("-v", "--verbose",
+    action="count", default=0,
+    help="Increases the verbosity of the output: -v will print results that "
+      "were reported to standard out. Otherwise only errors are printed.")
   report_parser.add_argument("-f", "--finalize",
     help="Finalize the grade (mark as ready/klarmarkera) for examiner to attest",
     action="store_true",
